import * as react_jsx_runtime from 'react/jsx-runtime';
import { FormProps } from '@rjsf/core';
import { WidgetProps, StrictRJSFSchema, RJSFSchema, FormContextType, ArrayFieldTemplateProps, FieldTemplateProps, TitleFieldProps, ErrorListProps, UiSchema, SubmitButtonProps } from '@rjsf/utils';
import { FrIconClassName, RiIconClassName } from '@codegouvfr/react-dsfr';

declare function export_default$5(props: WidgetProps): react_jsx_runtime.JSX.Element;

declare function RadioWidget<T = any, S extends StrictRJSFSchema = RJSFSchema, F extends FormContextType = any>({ id, options, value, required, disabled, readonly, onChange, onBlur, onFocus, uiSchema, schema, }: WidgetProps<T, S, F>): react_jsx_runtime.JSX.Element;

declare function export_default$4<T = any, S extends StrictRJSFSchema = RJSFSchema, F extends FormContextType = any>({ label, rawErrors, autofocus, readonly, formContext, hideError, hideLabel, uiSchema, ...props }: WidgetProps<T, S, F>): react_jsx_runtime.JSX.Element;

type CustomWidgetProps<T = any, S extends StrictRJSFSchema = RJSFSchema, F extends FormContextType = any> = WidgetProps<T, S, F> & {
    options: any;
};
declare function WidgetTextarea<T = any, S extends StrictRJSFSchema = RJSFSchema, F extends FormContextType = any>({ id, placeholder, value, required, type, uiSchema, label, disabled, autofocus, readonly, hideError, formContext, rawErrors, options, onBlur, onFocus, onChange, ...rest }: CustomWidgetProps<T, S, F>): react_jsx_runtime.JSX.Element;

type IconsDSFR = FrIconClassName | RiIconClassName;
/** Custom UI options for array fields */
type ArrayFieldUiOptionsDSFR = {
    /** Icon for the add button */
    'ui:addIcon'?: IconsDSFR;
    /** Icon for the remove button */
    'ui:removeIcon'?: IconsDSFR;
    /** Label for tab component. */
    'ui:tabLabel'?: string;
};
/**
 * Array field are displayed in a Tabs component where:
 * - each tab corresponds to an element of the array,
 * - the last tab is an "add" button,
 * - tab label can be customized with `ui:tabLabel` and is numbered from 1,
 */
declare function export_default$3({ title, uiSchema, items, canAdd, onAddClick, }: ArrayFieldTemplateProps & {
    uiSchema?: UiSchemaDSFR;
}): react_jsx_runtime.JSX.Element;

declare function export_default$2<T = any, S extends StrictRJSFSchema = RJSFSchema, F extends FormContextType = any>({ id, placeholder, value, required, type, uiSchema, label, disabled, autofocus, readonly, hideError, formContext, rawErrors, options, onBlur, onFocus, onChange, ...rest }: WidgetProps<T, S, F>): react_jsx_runtime.JSX.Element;

declare function export_default$1({ classNames, style, errors, children, id, required, label, schema, uiSchema, }: FieldTemplateProps): react_jsx_runtime.JSX.Element;

declare function export_default(_: TitleFieldProps): null;

declare function ErrorList<T = any, S extends StrictRJSFSchema = RJSFSchema, F extends FormContextType = any>({ errors, registry }: ErrorListProps<T, S, F>): react_jsx_runtime.JSX.Element;

type UiSchemaDSFR<T = any, S extends StrictRJSFSchema = RJSFSchema, F extends FormContextType = any> = UiSchema<T, S, F> & FieldUiOptionsDSFR & ArrayFieldUiOptionsDSFR;
/** Custom UI options for all fields.
 * see https://rjsf-team.github.io/react-jsonschema-form/docs/api-reference/uiSchema
 *
 */
type FieldUiOptionsDSFR = {
    /** Set the heading level for the title */
    'ui:heading'?: 'h2' | 'h3' | 'h4' | 'h5' | 'h6';
    /** To hide the title */
    'ui:hideTitle'?: boolean;
    /** Add description */
    'ui:description'?: string;
    /** Add help icon text after label */
    'ui:help'?: string;
};
type FormPropsDSFR<T = any, S extends StrictRJSFSchema = RJSFSchema, F extends FormContextType = any> = FormProps<T, S, F> & {
    uiSchema?: UiSchemaDSFR<T, S, F>;
};
/**
 * Form component with default DSFR widgets and templates.
 *
 * @param props - classic react-jsonschema-form props
 *
 * @returns a react-jsonschema-form Form component with DSFR widgets and templates
 */
declare function FormDSFR<T = any, S extends StrictRJSFSchema = RJSFSchema, F extends FormContextType = any>({ widgets, templates, validator, ...rest }: FormPropsDSFR<T, S, F>): react_jsx_runtime.JSX.Element;
declare const widgetsDSFR: {
    CheckboxWidget: typeof export_default$5;
    RadioWidget: typeof RadioWidget;
    SelectWidget: typeof export_default$4;
    TextareaWidget: typeof WidgetTextarea;
};
declare const templatesDSFR: {
    ArrayFieldTemplate: typeof export_default$3;
    BaseInputTemplate: typeof export_default$2;
    FieldTemplate: typeof export_default$1;
    ButtonTemplates: {
        SubmitButton: typeof SubmitButton;
    };
    TitleFieldTemplate: typeof export_default;
    ErrorListTemplate: typeof ErrorList;
};
declare function SubmitButton({ uiSchema }: SubmitButtonProps): react_jsx_runtime.JSX.Element;

export { type FieldUiOptionsDSFR, type FormPropsDSFR, type UiSchemaDSFR, FormDSFR as default, templatesDSFR, widgetsDSFR };
