// src/index.tsx
import Form from "@rjsf/core";
import defaultValidator from "@rjsf/validator-ajv8";
import { Button as Button2 } from "@codegouvfr/react-dsfr/Button";

// src/components/WidgetCheckBox.tsx
import Checkbox from "@codegouvfr/react-dsfr/Checkbox";

// src/components/LabelWithHelp.tsx
import { fr } from "@codegouvfr/react-dsfr";
import { useState } from "react";
import { jsx, jsxs } from "react/jsx-runtime";
function LabelWithHelp({
  helpText,
  children,
  as = "span",
  ...rest
}) {
  const [showHelp, setShowHelp] = useState(false);
  const Content = as;
  if (children == void 0) {
    return null;
  }
  return /* @__PURE__ */ jsxs("div", { className: "flex flex-col ", children: [
    /* @__PURE__ */ jsx("div", { className: "flex", style: { alignItems: "center" }, children: /* @__PURE__ */ jsxs(Content, { ...rest, children: [
      children,
      helpText ? /* @__PURE__ */ jsx(
        "i",
        {
          style: { cursor: "pointer" },
          className: fr.cx(
            "fr-icon--sm",
            "fr-ml-1w",
            !showHelp ? "fr-icon-information-line" : "fr-icon-information-fill"
          ),
          onClick: () => setShowHelp(!showHelp)
        }
      ) : null
    ] }) }),
    showHelp ? /* @__PURE__ */ jsx("p", { className: "fr-hint-text", children: helpText }) : null
  ] });
}

// src/components/WidgetCheckBox.tsx
import { jsx as jsx2 } from "react/jsx-runtime";
function WidgetCheckBox_default(props) {
  return /* @__PURE__ */ jsx2("div", { style: { marginTop: "1rem", marginBottom: "-1rem" }, children: /* @__PURE__ */ jsx2(
    Checkbox,
    {
      options: [
        {
          label: /* @__PURE__ */ jsx2(
            LabelWithHelp,
            {
              helpText: props.uiSchema !== void 0 ? props.uiSchema["ui:help"] : void 0,
              children: props.schema.title + (props.required ? "*" : "")
            }
          ),
          nativeInputProps: {
            checked: props.value,
            onChange: (e) => props.onChange(e.target.checked)
          }
        }
      ]
    }
  ) });
}

// src/components/WidgetRadio.tsx
import {
  enumOptionsValueForIndex
} from "@rjsf/utils";
import RadioButtons from "@codegouvfr/react-dsfr/RadioButtons";
import { jsx as jsx3 } from "react/jsx-runtime";
function RadioWidget({
  id,
  options,
  value,
  required,
  disabled,
  readonly,
  onChange,
  onBlur,
  onFocus,
  uiSchema,
  schema
}) {
  const { enumOptions, enumDisabled, emptyValue } = options;
  const _onChange = ({ target: { value: value2 } }) => onChange(enumOptionsValueForIndex(value2, enumOptions, emptyValue));
  const _onBlur = ({ target: { value: value2 } }) => onBlur(id, enumOptionsValueForIndex(value2, enumOptions, emptyValue));
  const _onFocus = ({ target: { value: value2 } }) => onFocus(id, enumOptionsValueForIndex(value2, enumOptions, emptyValue));
  const inline = Boolean(options && options.inline);
  return /* @__PURE__ */ jsx3("div", { style: { marginTop: "1rem", marginBottom: "-1rem" }, children: /* @__PURE__ */ jsx3(
    RadioButtons,
    {
      options: options && options.enumOptions?.map((option) => ({
        label: /* @__PURE__ */ jsx3(
          LabelWithHelp,
          {
            helpText: uiSchema !== void 0 ? uiSchema["ui:help"] : void 0,
            children: option.label
          }
        ),
        nativeInputProps: {
          checked: value === option.value,
          onChange: (e) => onChange(option.value)
        }
      })) || []
    }
  ) });
}

// src/components/WidgetSelect.tsx
import Select from "@codegouvfr/react-dsfr/Select";
import {
  enumOptionsIndexForValue,
  enumOptionsValueForIndex as enumOptionsValueForIndex2,
  getUiOptions
} from "@rjsf/utils";
import { useCallback } from "react";
import { jsx as jsx4, jsxs as jsxs2 } from "react/jsx-runtime";
function WidgetSelect_default({
  label,
  rawErrors,
  autofocus,
  readonly,
  formContext,
  hideError,
  hideLabel,
  uiSchema,
  ...props
}) {
  const { enumOptions, emptyValue: optEmptyVal } = props.options;
  const handleChange = useCallback(
    (event) => {
      const newValue = getValue(event, props.multiple ?? false);
      return props.onChange(
        enumOptionsValueForIndex2(
          newValue,
          enumOptions,
          optEmptyVal
        )
      );
    },
    [props.onChange, props.schema, props.multiple, props.options]
  );
  const selectedIndexes = enumOptionsIndexForValue(
    props.value,
    props.options.enumOptions,
    props.multiple
  );
  const defaultIndex = enumOptionsIndexForValue(
    props.schema.default,
    props.options.enumOptions,
    props.multiple
  );
  const value = typeof selectedIndexes === "undefined" ? defaultIndex : selectedIndexes;
  const uiOptions = getUiOptions(uiSchema);
  const backgroundColor = uiOptions.backgroundColor || "auto";
  return /* @__PURE__ */ jsxs2(
    Select,
    {
      nativeSelectProps: {
        id: props.id,
        name: props.name,
        required: props.required,
        value,
        onChange: handleChange,
        style: { backgroundColor }
      },
      label: void 0,
      ...props,
      children: [
        !props.multiple && props.schema.default === void 0 && props.options.placeholder && /* @__PURE__ */ jsx4("option", { value: "", disabled: true, children: props.options.placeholder }),
        props.options.enumOptions?.map((item, index) => /* @__PURE__ */ jsx4("option", { value: String(index), children: item.label }, index)),
        "state=",
        rawErrors && rawErrors.length ? "error" : "default",
        "stateRelatedMessage=",
        rawErrors?.length && rawErrors[0]
      ]
    }
  );
}
function getValue(event, multiple) {
  if (multiple) {
    return Array.from(event.target.options).slice().filter((o) => o.selected).map((o) => o.value);
  }
  return event.target.value;
}

// src/components/WidgetTextarea.tsx
import {
  getUiOptions as getUiOptions2
} from "@rjsf/utils";
import Input from "@codegouvfr/react-dsfr/Input";
import { jsx as jsx5 } from "react/jsx-runtime";
function WidgetTextarea({
  id,
  placeholder,
  value,
  required,
  type,
  uiSchema,
  label,
  disabled,
  autofocus,
  readonly,
  hideError,
  formContext,
  rawErrors,
  options,
  onBlur,
  onFocus,
  onChange,
  ...rest
}) {
  const uiOptions = getUiOptions2(uiSchema);
  const rows = uiOptions.rows || 3;
  const backgroundColor = uiOptions.backgroundColor || "auto";
  return /* @__PURE__ */ jsx5(
    Input,
    {
      textArea: true,
      nativeTextAreaProps: {
        rows,
        required,
        placeholder,
        autoFocus: autofocus,
        readOnly: readonly,
        value,
        onChange: (e) => onChange(e.target.value),
        style: { backgroundColor }
      },
      state: rawErrors && rawErrors.length ? "error" : "default",
      stateRelatedMessage: rawErrors?.length && rawErrors[0],
      disabled,
      label: void 0,
      ...rest
    }
  );
}

// src/components/TemplateArrayField.tsx
import Button from "@codegouvfr/react-dsfr/Button";
import Tabs from "@codegouvfr/react-dsfr/Tabs";
import { Fragment, jsx as jsx6, jsxs as jsxs3 } from "react/jsx-runtime";
function TemplateArrayField_default({
  title,
  uiSchema,
  items,
  canAdd,
  onAddClick
}) {
  const tabLabel = uiSchema?.["ui:tabLabel"] ?? "Element";
  const removeIcon = uiSchema?.["ui:removeIcon"] ?? "fr-icon-delete-line";
  const addIcon = uiSchema?.["ui:addIcon"] ?? "fr-icon-add-circle-line";
  console.log("items", items);
  return /* @__PURE__ */ jsx6("div", { className: "form-group field", children: /* @__PURE__ */ jsxs3("div", { className: "fr-input-group", children: [
    /* @__PURE__ */ jsx6("label", { className: "fr-label", children: title }),
    /* @__PURE__ */ jsx6("div", { className: "fr-input-wrap", children: /* @__PURE__ */ jsx6(
      Tabs,
      {
        tabs: items.map((element) => ({
          label: `${tabLabel} ${element.index + 1}`,
          content: /* @__PURE__ */ jsxs3(Fragment, { children: [
            /* @__PURE__ */ jsx6(
              Button,
              {
                type: "button",
                iconId: removeIcon,
                onClick: (e) => {
                  console.log("io", element);
                  element.onDropIndexClick(element.index);
                },
                size: "small",
                priority: "secondary",
                children: "Supprimer"
              }
            ),
            element.children
          ] })
        })).concat([
          {
            label: `Ajouter`,
            content: /* @__PURE__ */ jsx6(Fragment, { children: canAdd && /* @__PURE__ */ jsx6(
              Button,
              {
                type: "button",
                iconId: addIcon,
                onClick: onAddClick,
                size: "small",
                priority: "secondary",
                children: "Ajouter"
              }
            ) })
          }
        ])
      }
    ) })
  ] }) });
}

// src/components/TemplateBaseInput.tsx
import Input2 from "@codegouvfr/react-dsfr/Input";
import {
  getUiOptions as getUiOptions3
} from "@rjsf/utils";
import { jsx as jsx7 } from "react/jsx-runtime";
function TemplateBaseInput_default({
  id,
  placeholder,
  value,
  required,
  type,
  uiSchema,
  label,
  disabled,
  autofocus,
  readonly,
  hideError,
  formContext,
  rawErrors,
  options,
  onBlur,
  onFocus,
  onChange,
  ...rest
}) {
  if (type === "date") {
    value = uiSchema && uiSchema["ui:currentDate"] ? value ?? (/* @__PURE__ */ new Date()).toISOString().split("T")[0] : value;
    onChange(value);
  }
  const uiOptions = getUiOptions3(uiSchema);
  const inputType = uiOptions.inputType || type;
  const backgroundColor = uiOptions.backgroundColor || "auto";
  return /* @__PURE__ */ jsx7(
    Input2,
    {
      disabled,
      nativeInputProps: {
        type: inputType,
        required,
        placeholder,
        autoFocus: autofocus,
        readOnly: readonly,
        value,
        onChange: (e) => onChange(e.target.value),
        min: rest.schema.minimum,
        style: { backgroundColor }
      },
      state: rawErrors && rawErrors.length ? "error" : "default",
      stateRelatedMessage: rawErrors?.length && rawErrors[0],
      label: void 0,
      ...rest
    }
  );
}

// src/components/TemplateField.tsx
import { jsx as jsx8, jsxs as jsxs4 } from "react/jsx-runtime";
var schemaTypesToNotRenderTitles = ["boolean", "array"];
function TemplateField_default({
  classNames,
  style,
  errors,
  children,
  id,
  required,
  label,
  schema,
  uiSchema
}) {
  let title = null;
  let heading = uiSchema && uiSchema["ui:heading"];
  if (heading != void 0) {
    switch (heading) {
      case "h3":
        title = /* @__PURE__ */ jsx8("h3", { className: "fr-h3", children: label });
        break;
      case "h4":
        title = /* @__PURE__ */ jsx8("h4", { className: "fr-h4", children: label });
        break;
      case "h5":
        title = /* @__PURE__ */ jsx8("h5", { className: "fr-h5", children: label });
        break;
      case "h6":
        title = /* @__PURE__ */ jsx8("h6", { className: "fr-h6", children: label });
        break;
      default:
        title = /* @__PURE__ */ jsx8("h2", { className: "fr-h2", children: label });
        break;
    }
  } else {
    title = !schemaTypesToNotRenderTitles.includes(schema.type) ? !uiSchema || !uiSchema["ui:hideTitle"] ? /* @__PURE__ */ jsx8(
      LabelWithHelp,
      {
        helpText: uiSchema ? uiSchema["ui:help"] : void 0,
        as: "label",
        htmlFor: id,
        className: "fr-label",
        children: label + (required ? " (obligatoire)" : "")
      }
    ) : null : null;
  }
  const description = uiSchema && uiSchema["ui:description"];
  return /* @__PURE__ */ jsxs4("div", { className: classNames + " fr-mt-1w", style, children: [
    title,
    description && /* @__PURE__ */ jsx8("p", { className: "fr-hint-text", children: description }),
    children
  ] });
}

// src/components/TemplateTitleField.tsx
function TemplateTitleField_default(_) {
  return null;
}

// src/components/ErrorList.tsx
import Alert from "@codegouvfr/react-dsfr/Alert";
import { jsx as jsx9 } from "react/jsx-runtime";
function ErrorList({ errors, registry }) {
  const { translateString } = registry;
  return /* @__PURE__ */ jsx9(
    Alert,
    {
      severity: "error",
      title: "Erreurs",
      description: /* @__PURE__ */ jsx9("ul", { children: errors.map((error, i) => {
        return /* @__PURE__ */ jsx9("li", { className: "border-0", children: /* @__PURE__ */ jsx9("span", { children: error.stack }) }, i);
      }) })
    }
  );
}

// src/index.tsx
import { jsx as jsx10 } from "react/jsx-runtime";
function FormDSFR({ widgets, templates, validator, ...rest }) {
  return /* @__PURE__ */ jsx10(
    Form,
    {
      validator: validator ?? defaultValidator,
      widgets: widgets !== void 0 ? {
        ...widgetsDSFR,
        ...widgets
      } : widgetsDSFR,
      templates: templates !== void 0 ? {
        ...templatesDSFR,
        ...templates
      } : templatesDSFR,
      ...rest
    }
  );
}
var widgetsDSFR = {
  CheckboxWidget: WidgetCheckBox_default,
  RadioWidget,
  SelectWidget: WidgetSelect_default,
  TextareaWidget: WidgetTextarea
};
var templatesDSFR = {
  ArrayFieldTemplate: TemplateArrayField_default,
  BaseInputTemplate: TemplateBaseInput_default,
  FieldTemplate: TemplateField_default,
  ButtonTemplates: { SubmitButton },
  TitleFieldTemplate: TemplateTitleField_default,
  ErrorListTemplate: ErrorList
};
function SubmitButton({ uiSchema }) {
  const buttonOptions = uiSchema?.["ui:options"]?.submitButtonOptions;
  const buttonProps = uiSchema?.["ui:options"]?.submitButtonOptions?.props || {};
  return (
    // NOTE: should the div stay here? Probably not.
    /* @__PURE__ */ jsx10("div", { className: "flex w-full fr-mt-2w", children: /* @__PURE__ */ jsx10(Button2, { ...buttonProps, children: buttonOptions?.submitText ?? "Envoyer" }) })
  );
}
export {
  FormDSFR as default,
  templatesDSFR,
  widgetsDSFR
};
//# sourceMappingURL=index.js.map